--
-- FileUtils.hs
--
-- Copyright (c) 2003 Minero Aoki <aamine@loveruby.net>
--
-- This program is free software.
-- You can distribute/modify this program under the terms of
-- the GNU LGPL, Lesser General Public License version 2.
-- For details of the GNU LPGL, see the file "COPYING".
--

module Href.FileUtils (glob0, traverseDirectory) where

import System.IO
import System.Directory
import Control.Monad
import Data.List
import Text.Regex

glob0 :: String -> Regex -> IO [String]
glob0 dir re = do
    es <- traverseDirectory dir
    filterM (\e -> case matchRegex re e of
                     Just _ -> return True
                     Nothing -> return False) es

traverseDirectory :: String -> IO [String]
traverseDirectory dir = do
    ok <- doesDirectoryExist dir
    if (not ok)
      then return [dir]
      else do es <- getDirectoryContents dir
              es' <- mapM (\e -> case e of
                                   "." -> return [dir]
                                   ".." -> return []
                                   _ -> traverseDirectory $ dir ++ "/" ++ e) es
              return $ concat es'
