--
-- TextUtils.hs
--
-- Copyright (c) 2003 Minero Aoki <aamine@loveruby.net>
--
-- This program is free software.
-- You can distribute/modify this program under the terms of
-- the GNU LGPL, Lesser General Public License version 2.
-- For details of the GNU LPGL, see the file "COPYING".
--

module Href.TextUtils (split, split2, join, basename, dirname) where

join :: [a] -> [[a]] -> [a]
join sep words = foldl1 (\xs ys -> xs ++ sep ++ ys) words

split :: Eq a => a -> [a] -> [[a]]
split sep [] = []
split sep xs = x : split sep y'
               where (x,y) = break (==sep) xs
                     y' = case y of
                            [] -> []
                            _ -> tail y

split2 :: Eq c => c -> [c] -> ([c],[c])
split2 c [] = ([],[])
split2 c cs = (a, tail b) where (a,b) = break (==c) cs

basename :: String -> String
basename path = let npath = normalizePath path
                in case npath of
                     "/" -> "/"
                     _   -> last $ split '/' npath

dirname :: String -> String
dirname path = let npath = normalizePath path
               in case npath of
                    "/" -> "/"
                    _   -> join "/" $ init (split '/' npath)

normalizePath :: String -> String
normalizePath path = removeCurrent (removeParent (removeSlash path))

removeSlash :: String -> String
removeSlash "/"  = "/"
removeSlash path = if last path == '/'
                     then init path
                     else path

-- remove "any/../"
removeParent :: String -> String
removeParent path = path    -- FIXME

-- remove "/./"
removeCurrent :: String -> String
removeCurrent path = path    -- FIXME
