--
-- mkhref.hs
--
-- Copyright (c) 2003 Minero Aoki <aamine@loveruby.net>
--
-- This program is free software.
-- You can distribute/modify this program under the terms of
-- the GNU LGPL, Lesser General Public License version 2.
-- For details of the GNU LPGL, see the file "COPYING".
--

module Main where

import System
import System.IO
import System.Directory
import Control.Monad
import Data.Char
import Data.List

import Href.TextUtils
import Href.HrefUtils
import Href.Config

main :: IO ()
main = do ok <- doesDirectoryExist hrefPrefix
          when (not ok)
              (createDirectory hrefPrefix)
          args <- getArgs
          mapM_ (\path -> do
              cs <- readFile path
              placeChunks (hrefPrefix ++ "/" ++ (encodePath $ basename path))
                          (parse $ lines cs)) args

placeChunks :: String -> [(String,String)] -> IO ()
placeChunks dir []     = return ()
placeChunks dir (x:xs) =
    let (name,chunk) = x
    in do ok <- doesDirectoryExist dir
          when (not ok)
              (createDirectory dir)
          f <- openFile (dir ++ "/" ++ encodePath name) WriteMode
          hPutStrLn f chunk
          hClose f
          placeChunks dir xs

parse :: [String] -> [(String,String)]
parse []     = []
parse (x:xs) = (getFunctionName x, unlines $ x:chunk) : parse rest
               where (chunk, rest) = break (isAlpha.headChar) xs

getFunctionName :: String -> String
getFunctionName line = case head w2 of
                         '(' -> w1
                         ':' -> w1
                         _   -> w2
                       where (w1:w2:xs) = words line
